
# Slot: has output


A chemical entity that is the output for the reaction

URI: [biolink:molecular_activity_has_output](https://w3id.org/biolink/vocab/molecular_activity_has_output)


## Domain and Range

[MolecularActivity](MolecularActivity.md) &#8594;  <sub>0..\*</sub> [ChemicalSubstance](ChemicalSubstance.md)

## Parents

 *  is_a: [has output](has_output.md)

## Children


## Used by

 * [MolecularActivity](MolecularActivity.md)
